**To disable an existing entity**

The following ``deregister-from-work-mail`` command disables an existing entity (user, group, or resource) from using Amazon WorkMail. ::

    aws workmail deregister-from-work-mail \
        --organization-id m-d281d0a2fd824be5b6cd3d3ce909fd27 \
        --entity-id S-1-1-11-1111111111-2222222222-3333333333-3333

This command produces no output.
